#
# spec file for package frozen-bubble
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           frozen-bubble
# 2.212 == 2.2.1beta1
Version:        2.212
Release:        17.3
Summary:        Puzzle with Bubbles
License:        GPL-2.0-or-later
Group:          Amusements/Games/Action/Arcade
URL:            http://www.frozen-bubble.org/
Source0:        http://www.frozen-bubble.org/data/frozen-bubble-2.2.1-beta1.tar.bz2
Source1:        fb-server
Source2:        fb-server.service
# PATCH-FIX-OPENSUSE frozen-bubble-2.212-configpath.patch
Patch1:         frozen-bubble-2.212-configpath.patch
# PATCH-FIX-OPENSUSE msgfmt.diff
Patch2:         msgfmt.diff
# PATCH-FIX-UPSTREAM frozen-bubble-2.212-unused-result.patch
Patch3:         frozen-bubble-2.212-unused-result.patch
# PATCH-FEATURE-UPSTREAM https://github.com/kthakore/frozen-bubble/pull/63
Patch4:         desktop.patch
# PATCH-FEATURE-UPSTREAM https://github.com/kthakore/frozen-bubble/pull/64
Patch5:         appdata.patch
# PATCH-FIX-OPENSUSE get a strange check silent - what's the sense of checking snprintf when the buffer size is correct
Patch6:         silencebadsnprintfcheck.patch
# PATCH-FIX-OPENSUSE fix build with perl 5.40
Patch7:         perl-5.40.patch
BuildRequires:  Mesa-devel
BuildRequires:  SDL_Pango-devel
BuildRequires:  SDL_image-devel
BuildRequires:  SDL_mixer-devel
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  perl-SDL >= 2.400
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  perl(Alien::SDL)
BuildRequires:  perl(Compress::Bzip2)
BuildRequires:  perl(File::Slurp)
BuildRequires:  perl(IPC::System::Simple)
BuildRequires:  perl(Locale::Maketext::Extract)
BuildRequires:  perl(Locale::Maketext::Lexicon)
BuildRequires:  perl(Locale::Maketext::Simple)
BuildRequires:  perl(Locale::Msgfmt)
BuildRequires:  perl(Module::Build)
BuildRequires:  perl(Tie::Simple)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(systemd)
# Fix for: Failed loading SDL2 library on openSUSE Leap
%if 0%{?suse_version} <= 1500
BuildRequires:  pkgconfig(sdl2)
%endif
Requires:       %{name}-server = %{version}
Requires:       perl = %{perl_version}
Requires:       perl-SDL >= 2.400
Requires:       perl(Alien::SDL)
Requires:       perl(Compress::Bzip2)
Requires:       perl(Locale::Maketext::Lexicon)
Requires:       perl(Locale::Maketext::Simple)
Requires:       perl(Tie::Simple)
Requires(pre):  %fillup_prereq
Requires(pre):  net-tools
Recommends:     %{name}-lang

%description
Shoot up bubbles. Similar to the console game Puzzle-Bobble.

Colorful 3D rendered penguin animations, 100 levels of 1p game, hours and
hours of 2p game, nights and nights of 2p/3p/4p/5p game over LAN or Internet,
a level-editor, 3 professional quality digital soundtracks, 15 stereo sound
effects, 8 unique graphical transition effects, 8 unique logo eye-candies.

%package server
Summary:        Puzzle with Bubbles - Server
Group:          Amusements/Games/Action/Arcade
Requires(post): coreutils
%{?systemd_requires}

%description server
Server for frozen-bubble.

Colorful 3D rendered penguin animations, 100 levels of 1p game, hours and
hours of 2p game, nights and nights of 2p/3p/4p/5p game over LAN or Internet,
a level-editor, 3 professional quality digital soundtracks, 15 stereo sound
effects, 8 unique graphical transition effects, 8 unique logo eye-candies.

%lang_package

%prep
%setup -q -n frozen-bubble-2.2.1-beta1
cp server/init/README server/README.init
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1
%patch -P 6 -p1
%patch -P 7 -p1

%build
perl Build.PL destdir=%{buildroot} installdirs=vendor --prefix=%{_prefix}
./Build manifest
./Build

%check
./Build test

%install
install -d -m 1755 %{buildroot}%{_datadir}/%{name}
./Build install

mv %{buildroot}%{perl_vendorarch}/auto/share/dist/Games-FrozenBubble/* %{buildroot}%{_datadir}/%{name}/

for res in 64x64 48x48 32x32 16x16; do
    install -Dm644 share/icons/frozen-bubble-icon-$res.png %{buildroot}%{_datadir}/icons/hicolor/$res/apps/%{name}.png
done

mkdir -p %{buildroot}%{_datadir}/applications/
install -m 644 share/%{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop

mkdir -p %{buildroot}%{_datadir}/appdata/
install -m 644 share/%{name}.appdata.xml %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

mkdir -p %{buildroot}%{_unitdir} %{buildroot}/%{_sbindir}
install -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/frozen-bubble-server.service
ln -s /sbin/service %{buildroot}%{_sbindir}/rcfb-server
ln -s /sbin/service %{buildroot}%{_sbindir}/rcfrozen-bubble-server

install -d -m 755 %{buildroot}/%{_sysconfdir}
touch %{buildroot}/%{_sysconfdir}/fb-server.conf

%fdupes %{buildroot}${_datadir}
%perl_process_packlist

%post server
%fillup_only
%service_add_post frozen-bubble-server.service
if [ ! -f "%{_sysconfdir}/fb-server.conf" ]; then
  if [ -f "%{_sysconfdir}/language" ]; then
	. %{_sysconfdir}/language
	lang=$(echo ${RC_LANG%*_*})
  fi
  if [ -n "$lang" -o "$lang" = "" ]; then
	lang="en"
  fi
  if [ -x /bin/hostname ]; then
	servername=$(hostname -s)
  else
	servername="testserver"
  fi
  cat > %{_sysconfdir}/fb-server.conf << EOF
# Specify the desired language of the server below (it is just an
# indication used by players when choosing a server, so that
# they can chat using their native language). You can specify none
# with the parameterless option 'z'.
# Name of the server as seen by FB players
n $servername
# Preferred language of players
a $lang
EOF
fi

%postun server
%service_del_postun frozen-bubble-server.service

%pre server
%service_add_pre frozen-bubble-server.service

%preun server
%service_del_preun frozen-bubble-server.service

%files
%license COPYING
%doc AUTHORS README
%dir %{perl_vendorarch}/Games
%dir %{perl_vendorarch}/Games/FrozenBubble
%dir %{perl_vendorarch}/auto/Games
%dir %{perl_vendorarch}/auto/Games/FrozenBubble
%{perl_vendorarch}/Games/FrozenBubble/*
%{perl_vendorarch}/Games/FrozenBubble.pm
%{perl_vendorarch}/auto/Games/FrozenBubble/CStuff*
%{_bindir}/%{name}
%{_bindir}/frozen-bubble-editor
%{_datadir}/%{name}/
%exclude %{_datadir}/%{name}/locale/*.po
%attr (644,root,root) %{_mandir}/man*/frozen-bubble*
%attr (644,root,root) %{_mandir}/man*/Games*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml

%files server
%license COPYING
%doc server/AUTHORS server/README* server/init/fb-server.conf
%ghost %config(noreplace) %{_sysconfdir}/fb-server.conf
%defattr(755, root, root)
%{_bindir}/fb-server
%attr (644,root,root) %{_unitdir}/frozen-bubble-server.service
%{_sbindir}/rcfb-server
%{_sbindir}/rcfrozen-bubble-server

%files lang
%defattr(-,root,root,-)
# Don't find a solution to install locales on standard directory
%{_datadir}/%{name}/locale/*.po

%changelog
* Fri Jul  5 2024 Giacomo Comes <gcomes.obs@gmail.com>
- add patch perl-5.40.patch
  * fix build with perl 5.40
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Nov 28 2022 Carsten Ziepke <kieltux@gmail.com>
- Add BuildRequires SDL2 for openSUSE Leap, fix for building
- Run spec-cleaner
* Mon Jun 18 2018 opensuse@dstoecker.de
- fix build for Tumbleweed (add silencebadsnprintfcheck.patch)
* Mon Mar  5 2018 dimstar@opensuse.org
- Add Requires(post): coreutils to server subpackage: the post
  script calls 'cat' (boo#839736).
* Wed Aug 24 2016 rpm@fthiessen.de
- Use bundled icons and install all resolutions available.
- Removed code in spec for now unmaintained openSUSE versions.
* Tue Aug 23 2016 mailaender@opensuse.org
- Add appdata.patch and desktop.patch for inclusion in
  https://software.opensuse.org/packages/Games
- Avoid deprecated pixmap icon folder.
- Use https://en.opensuse.org/SourceUrls
- Add missing desktop/icon post macros.
* Sat Aug 29 2015 bwiedemann@suse.com
- BuildRequire perl(Module::Build)
* Sun Jan 25 2015 devel.suse@gmail.com
- Remove exec bit from frozen-bubble-server.service
* Sun Aug  3 2014 sfalken@opensuse.org
- Changed $PIDDIR in fb-server to /run/fb-server, instead of /var/run
  Removed references to /run in .spec file, per discussion on OBS request #243074
- Modified:
    frozen-bubble.spec
    fb-server
* Wed Jul 30 2014 sfalken@opensuse.org
- Changed paths in .spec file from /var/run to /run to resolve rpmlint check failures in oS:Factory
* Sun Oct 27 2013 p.drouand@gmail.com
- Add systemd support for openSUSE >= 12.3
- Add a language subpackage
* Thu Dec 20 2012 joop.boonen@opensuse.org
- Added missing BuildRequirements
- Created unused-result patch
- Build manifest
* Wed Sep 19 2012 opensuse@dstoecker.de
- update to 2.212 (2.2.1beta1)
  * use new SDL Perl API
  * ported to CPAN; should now work "natively" on Windows and Mac OSX
  * integrates all functional openSUSE patches
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sun Nov 20 2011 dimstar@opensuse.org
- Create /var/run/fb-server so we can package it. Fixes build on
  12.1 / Factory.
* Fri Aug 26 2011 prusnak@opensuse.org
- package /var/run as %%ghost [bnc#710295]
* Mon Dec 27 2010 dimstar@opensuse.org
- Fix build on openSUSE 11.4.
* Thu Oct 15 2009 lrupp@suse.de
- add frozen-bubble-server as Provides to init script
* Sat Oct  3 2009 lars@linux-schulserver.de
- build all packages via one single specfile
- add $remote_fs to init-skript as /usr can be remote
- added 'status' and 'try-restart' options to init-script
- use /etc/init.d/frozen-bubble-server to be lsb conform
- optimize the code
- added frozen-bubble-2.2.0-total_launched_bubbles.patch
- added frozen-bubble-2.2.0-german.patch
- generate a primary working fb-server.conf on installation
- fix PreReq
* Wed May 20 2009 prusnak@suse.cz
- cleaned-up Requires and BuildRequires list
* Mon Dec  8 2008 opensuse@dstoecker.de
- updated to 2.2.0 final release
* Mon Dec  1 2008 opensuse@dstoecker.de
- updated to 2.2.0 RC2
* Tue Nov  4 2008 opensuse@dstoecker.de
- updated to 2.2.0 RC1 (removing two now integrated patches)
- NOTE that connections to older FB servers are no longer possible
* Fri Jun 27 2008 sndirsch@suse.de
- verified that dstoecker's changes are fine
* Fri Jun 27 2008 opensuse@dstoecker.de
- updated to current SVN version integrating lots of the patches
- fixed server starts script for 64 bit systems (bnc #404439)
* Mon Mar 10 2008 opensuse@dstoecker.de
- added /autokick command and messages for /kick
* Sun Feb 24 2008 crrodriguez@suse.de
- user find_lang macro
- frozen-bubble-server failed to call restart_on_update, stop_on_removal
  and insserv_cleanup macros properly
* Wed Jan 30 2008 ro@suse.de
- fix missing prototype (logging_init)
* Mon Jan 14 2008 coolo@suse.de
- CheckHardware is dropped
* Thu Oct  4 2007 opensuse@dstoecker.de
- fixed LAN game server selection problem (Bug #336294)
- fixed LAN game server creation with long nickname
* Sun Sep 30 2007 sndirsch@suse.de
- added -server subpackage and a lot of patches by Dirk Stoecker
* Fri Sep 21 2007 sndirsch@suse.de
- make no use of %%optipng macro on openSUSE 10.2 (Bug #326968)
* Mon Sep 10 2007 sndirsch@suse.de
- make use of %%optipng macro (Bug #309087)
* Mon Dec 18 2006 sndirsch@suse.de
- removed bogus %%post/%%postun scripts (Bug #229374)
* Mon Dec 11 2006 dmueller@suse.de
- add missing require for .desktop file
* Wed Dec  6 2006 dmueller@suse.de
- don't build as root
* Sat Nov 25 2006 wstephenson@suse.de
- update to frozen-bubble 2.1.0
  * 1-player multiplayer training: ability to activate chain reaction
  * world map: you can view the amount of playing players, which helps chosing a server
  * world map: you see playing players as green dots
  * network game lounge: you can toggle fullscreen
  * network game lounge: the game creator can activate chain-reaction and set a victories limit through options
  * network game lounge: you can request server info
  * network game lounge: chat is timestampped
  * multiplayer: you can view who's attacking you
* Tue Nov  7 2006 sndirsch@suse.de
- added missing mini images for the colourblind balls (Bug #218841)
* Mon Nov  6 2006 sndirsch@suse.de
- fixed file permissions
* Mon Oct 30 2006 sndirsch@suse.de
- fixed sever startup for LAN game
* Sun Oct 29 2006 sndirsch@suse.de
- updated to frozen-bubble 2.0.0
  * new 1-player game mode: multiplayer training; uses identical
    game rules as multiplayer, generated malus bubbles are counted
    as points - what score will you be able to reach in the 2
    minutes time frame?
  * network (Internet) game: up to 5 players in a game (net game
    system has logic able to transparently handle players behind ai
    NAT)
  * LAN game: similar to network game except that no connection to
    Internet is made, substituted by polling the local network
  * fully revamped graphics, including now 3d-based smooth penguin
    eyecandy
  * revamped intro and 1p music into fully digital productions
  * full joystick support: just move your joystick(s) or push
    buttons in the "change keys" dialog (analog joysticks handled
    as digital for fair play)
  * recording and playback of all games with non-predefined levels
    (1-player in random and multiplayer training, local 2-player,
    and network/LAN game with 2 to 5 players)
  * realtime graphical effects in the menu screen (if your computer
    is fast enough)
  * anti-aliased and localized messages
* Sat Oct 28 2006 sndirsch@suse.de
- fixed startup
* Fri Sep  8 2006 sndirsch@suse.de
- fixed build in openSUSE buildservice / Bug #212212
* Thu Feb 16 2006 stbinner@suse.de
- add GenericName to .desktop file
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Sep  8 2005 sndirsch@suse.de
- fixed file permissions (#114849)
* Thu Jul 28 2005 sndirsch@suse.de
- added libmikmod to #neededforbuild
* Fri Jul 22 2005 sndirsch@suse.de
- added SDL_mixer-devel to #neededforbuild
* Fri Mar 19 2004 sndirsch@suse.de
- removed .orig files to fix build
* Mon Sep 22 2003 sndirsch@suse.de
- added 48x48 Icon as additional source
* Sat Aug 30 2003 sndirsch@suse.de
- added desktop icon
* Wed Aug 20 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Aug 18 2003 sndirsch@suse.de
- removed previous patch again as SDL_perl was downgraded to 1.20.0
  again
* Sat Aug 16 2003 sndirsch@suse.de
- added patch required for SDL_perl 2.0
* Sun Aug 10 2003 sndirsch@suse.de
- added desktop file
* Sun Jul 13 2003 sndirsch@suse.de
- fixed build
* Fri Jun 13 2003 sndirsch@suse.de
- fixed filelist
* Wed Jun  4 2003 sndirsch@suse.de
- fixed filelist for non-i386 archs
* Wed May 14 2003 sndirsch@suse.de
- fixed filelist
* Wed Apr 16 2003 coolo@suse.de
- use BuildRoot
* Mon Feb 17 2003 sndirsch@suse.de
- update to release 1.0.0
  * added: level editor, contributed by Kim and David Joham
  * added: 50 more levels, to make them 100 now
  * changed: graphics have been re-designed
  * added: chain-reaction mechanism in 2p-mode
  * added: manpages (first contributed by Debian)
* Sun Oct 27 2002 sndirsch@suse.de
- added missing 'Requires: SDL_perl'
* Fri Oct 25 2002 sndirsch@suse.de
- fixed %%files section (use macros now)
* Thu Oct 24 2002 sndirsch@suse.de
- created package
